@@ -1,6 +1,7 @@
 // SPDX-FileCopyrightText: 2010 Manjeet Dahiya <manjeetdahiya@gmail.com>
 // SPDX-FileCopyrightText: 2010 Jeremy Lainé <jeremy.laine@m4x.org>
 // SPDX-FileCopyrightText: 2020 Melvin Keskin <melvo@olomono.de>
+// SPDX-FileCopyrightText: 2024 Filipe Azevedo <pasnox@gmail.com>
 //
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
@@ -10,11 +11,13 @@
 #include "QXmppClient.h"
 #include "QXmppConstants_p.h"
 #include "QXmppFutureUtils_p.h"
+#include "QXmppMovedManager.h"
 #include "QXmppPresence.h"
 #include "QXmppRosterIq.h"
 #include "QXmppUtils.h"
 #include "QXmppUtils_p.h"
 
+#include "Algorithms.h"
 #include "StringLiterals.h"
 
 #include <QDomElement>
@@ -25,7 +28,9 @@ using namespace QXmpp::Private;
 namespace QXmpp::Private {
 
 struct RosterData {
-    QList<QXmppRosterIq::Item> items;
+    using Items = QList<QXmppRosterIq::Item>;
+
+    Items items;
 
     static std::variant<RosterData, QXmppError> fromDom(const QDomElement &el)
     {
@@ -69,8 +74,8 @@ static void serializeRosterData(const RosterData &d, QXmlStreamWriter &writer)
 /// The user can either accept the request by calling acceptSubscription() or refuse it
 /// by calling refuseSubscription().
 ///
-/// \note If QXmppConfiguration::autoAcceptSubscriptions() is set to true, this
-/// signal will not be emitted.
+/// \note If QXmppConfiguration::autoAcceptSubscriptions() is set to true or the subscription
+/// request is automatically accepted by the QXmppMovedManager, this signal will not be emitted.
 ///
 /// \param subscriberBareJid bare JID that wants to subscribe to the user's presence
 /// \param presence presence stanza containing the reason / message (presence.statusText())
@@ -259,23 +264,46 @@ void QXmppRosterManager::_q_presenceReceived(const QXmppPresence &presence)
         d->presences[bareJid].remove(resource);
         Q_EMIT presenceChanged(bareJid, resource);
         break;
-    case QXmppPresence::Subscribe:
+    case QXmppPresence::Subscribe: {
+        // accept all incoming subscription requests if enabled
         if (client()->configuration().autoAcceptSubscriptions()) {
-            // accept subscription request
-            acceptSubscription(bareJid);
-
-            // ask for reciprocal subscription
-            subscribe(bareJid);
-        } else {
-            Q_EMIT subscriptionReceived(bareJid);
-            Q_EMIT subscriptionRequestReceived(bareJid, presence);
+            handleSubscriptionRequest(bareJid, presence, true);
+            break;
         }
+
+        // check for XEP-0283: Moved subscription requests and verify them
+        if (auto *movedManager = client()->findExtension<QXmppMovedManager>()) {
+            if (auto verificationTask = movedManager->handleSubscriptionRequest(presence)) {
+                verificationTask->then(this, [this, presence, bareJid](bool valid) {
+                    handleSubscriptionRequest(bareJid, presence, valid);
+                });
+                break;
+            }
+        }
+
+        handleSubscriptionRequest(bareJid, presence, false);
         break;
+    }
     default:
         break;
     }
 }
 
+void QXmppRosterManager::handleSubscriptionRequest(const QString &bareJid, const QXmppPresence &presence, bool accept)
+{
+    if (accept) {
+        // accept subscription request
+        acceptSubscription(bareJid);
+
+        // ask for reciprocal subscription
+        subscribe(bareJid);
+    } else {
+        // let user decide whether to accept the subscription request
+        Q_EMIT subscriptionReceived(bareJid);
+        Q_EMIT subscriptionRequestReceived(bareJid, presence);
+    }
+}
+
 QXmppTask<QXmppRosterManager::RosterResult> QXmppRosterManager::requestRoster()
 {
     QXmppRosterIq iq;
@@ -523,41 +551,56 @@ void QXmppRosterManager::onRegistered(QXmppClient *client)
 {
     // data import/export
     if (auto manager = client->findExtension<QXmppAccountMigrationManager>()) {
-        using Result = std::variant<Success, QXmppError>;
-        auto importData = [this](const RosterData &data) -> QXmppTask<Result> {
+        using ImportResult = std::variant<Success, QXmppError>;
+        auto importData = [this, client, manager](const RosterData &data) -> QXmppTask<ImportResult> {
             if (data.items.isEmpty()) {
-                return makeReadyTask<Result>(Success());
+                return makeReadyTask<ImportResult>(Success());
             }
 
-            QXmppPromise<Result> promise;
+            QXmppPromise<ImportResult> promise;
             auto counter = std::make_shared<int>(data.items.size());
 
             for (const auto &item : std::as_const(data.items)) {
+                Q_ASSERT(!item.isMixChannel());
+
                 QXmppRosterIq iq;
                 iq.addItem(item);
                 iq.setType(QXmppIq::Set);
 
-                this->client()->sendGenericIq(std::move(iq)).then(this, [promise, counter](auto &&result) mutable {
+                client->sendGenericIq(std::move(iq)).then(this, [promise, counter](auto &&result) mutable {
                     if (promise.task().isFinished()) {
                         return;
                     }
 
-                    if (std::holds_alternative<QXmppError>(result)) {
-                        return promise.finish(std::get<QXmppError>(std::move(result)));
+                    if (auto error = std::get_if<QXmppError>(&result); error) {
+                        return promise.finish(std::move(*error));
                     }
 
                     if ((--(*counter)) == 0) {
-                        promise.finish(Success());
+                        return promise.finish(Success());
                     }
                 });
             }
 
             return promise.task();
         };
-
         auto exportData = [this]() {
             return chainMapSuccess(requestRoster(), this, [](QXmppRosterIq &&iq) -> RosterData {
-                return { iq.items() };
+                const auto items = transformFilter<RosterData::Items>(iq.items(), [](const auto &item) -> std::optional<QXmppRosterIq::Item> {
+                    if (item.isMixChannel()) {
+                        return {};
+                    }
+
+                    auto fixed = item;
+
+                    // We don't want this to be sent while importing.
+                    // See https://datatracker.ietf.org/doc/html/rfc6121#section-2.1.2.2
+                    fixed.setSubscriptionStatus({});
+
+                    return fixed;
+                });
+
+                return { items };
             });
         };
 
